-- ysdl example1.lua

-- Run this example using the ysdl minimal-main.c:
--
-- $ ysdl-minimal-main example1.lua
--
-- This expects to find its support files in the current directory.

-- require("strict")

-- check for ysdl
if not package.loaded["SDL"] or not SDL.ysdl_version then
  print("this example code must be run using a ysdl-enabled Lua!")
  os.exit(1)
end

-- declare global variables
screen = nil
screen_width = 640
screen_height = 480

image = nil
done = false

-- initialize SDL
if SDL.Init(SDL.INIT_EVERYTHING) == -1 then
  print("couldn't initialize SDL: " .. SDL.GetError())
  os.exit(1)
end

-- open 'screen' to render to
screen = SDL.SetVideoMode(screen_width, screen_height, 32, SDL.SWSURFACE)
if not screen then
  print("couldn't create screen: " .. SDL.GetError())
  os.exit(1)
end

-- set the window title
SDL.WM_SetCaption( "ysdl demo", nil )

-- set the background
screen:FillRect(screen:GetClipRect(), SDL.MapRGB_using_Surface(screen, 0, 0, 0x80))

-- load the foreground image
image = SDL.LoadBMP("example1-welcome.bmp")
if not image then
else
  -- optimize image for display
  local optimized = image:DisplayFormat()
  image:FreeSurface()
  image = optimized
end

-- set image background (black) to be transparent
local colorkey = SDL.MapRGB_using_Surface(image, 0, 0, 0)
-- if colorkey > 0xffffff then
--   colorkey = colorkey + 255  -- hack for SDL 1.2.14 Quartz backend on Tiger Intel
-- end
image:SetColorKey(SDL.SRCCOLORKEY, colorkey)

-- apply image to center of screen
local x, y = image:getSize()
local rect = SDL.newRect((screen_width - x) / 2,
                         (screen_height - y) / 2, 0, 0)
SDL.BlitSurface(image, nil, screen, rect)

-- paint the screen
screen:Flip()

-- wait for the user to quit
while not done do
  local event = SDL.PollEvent()
  while event do
    if event.type == SDL.QUIT or
       (event.type == SDL.KEYDOWN and event.sym == SDL.K_ESCAPE) then
      done = true
    end
    event = SDL.PollEvent()
  end
end

-- free resources
image:FreeSurface()

-- and we're done
SDL.Quit()

